﻿CREATE PROCEDURE InsertOrder
  @OrderedOn datetime2,
  @CustomerId int,
  @WineId int,
  @Quantity int
AS

  -- Don't permit zero or negative numbers for Quantity
  IF @Quantity < 1
   THROW 50000, 'Quantity must be 1 or more', 1;

  -- Derive unit price from Wine table 
  DECLARE @UnitPrice money = (SELECT Price FROM Wine WHERE WineId = @WineId);

  -- Ensure the specified Wine ID exists 
  IF @@ROWCOUNT = 0
   THROW 50000, 'The specified wine was not found', 1;

  -- Calculate total price
  DECLARE @Price money = @Quantity * @UnitPrice;

  -- Use the current date and time for AddedOn
  DECLARE @AddedOn datetime2 = SYSDATETIME();

  INSERT INTO [Order]
    (OrderedOn, CustomerId, WineId, Quantity, UnitPrice, Price, AddedOn)
   VALUES
    (@OrderedOn, @CustomerId, @WineId, @Quantity, @UnitPrice, @Price, @AddedOn);

  -- Return the new OrderId 
  SELECT OrderId = SCOPE_IDENTITY();
